@@ -2758,7 +2758,7 @@ void ChGL::draw(){//! draws everything some times by calling display lists.
           if (mol->showatoms.at(j).hidden) continue;
           if ((mol->nopm1)&&(mol->showatoms.at(j).symmGroup)&&(mol->showatoms.at(j).part<-0)) continue;
 	  if (imFokus==j) qglColor(QColor("#FFAA00")); else {
-	    if (mol->showatoms.at(j).symmGroup) {
+        if ((mol->highlightEquivalents)&&(mol->showatoms.at(j).symmGroup)) {
 	      if ((backGroundColor.saturation()>128)&&(abs(backGroundColor.hue()-240)<30)) qglColor(Qt::lightGray);
 	      else {
 		if (backGroundColor.value()<128) qglColor(QColor(Qt::blue).lighter(150));
