@@ -130,6 +130,7 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
   int top = (int) blockBoundingGeometry(block).translated(contentOffset()).top();
   int bottom = top + (int) blockBoundingRect(block).height();
   // printf ("line %d %d\n",top,bottom);
+  int minbl=8888888,maxbl=0;
   while (block.isValid() && top <= event->rect().bottom()) {
     if (block.isVisible() && bottom >= event->rect().top()) {
       QString number = QString::number(blockNumber + 1);
@@ -164,8 +165,11 @@ void CodeEditor::lineNumberAreaPaintEvent(QPaintEvent *event){
 		      lineNumberArea->width(), 
                       fontMetrics().lineSpacing () ,
                       Qt::AlignRight, number);
+      minbl=qMin(minbl,blockNumber + 1);
+      maxbl=qMax(maxbl,blockNumber + 1);
     }
-
+    if (ListFile)
+    midCursorpos=(minbl+maxbl)/2;
     block = block.next();
     top = bottom;
     bottom = top + (int) blockBoundingRect(block).height();
