@@ -68,6 +68,8 @@ class CodeEditor : public QPlainTextEdit {
 public:
     CodeEditor(QWidget *parent = 0);
     ~CodeEditor();
+    int midCursorpos;
+    bool ListFile;
     Highlighter *highlighter;//!< Highlighter is the syntax higlighter. 
     void setCompleter(QCompleter *c);//!< setCompleter sets the QCompleter for the editor.
     QCompleter *completer() const;//!< completer is the QCompleter
