@@ -34,6 +34,10 @@
 EacGLW::EacGLW(Molecule *externMole, QWidget * parent){
   this->setParent(parent);
   mol=externMole;
+  exmin=mol->pmin;
+  exmax=mol->pmax;
+  mol->pmax=0.99;
+  mol->pmin=0.39;
   //mol->copyAcol(mol->AtomColor,mol->arad,mol->AtomStyle);
   //mol->loadSettings();
   proba=50;
@@ -111,6 +115,45 @@ EacGLW::EacGLW(Molecule *externMole, QWidget * parent){
   xda.uc.m23=0.0;
   xda.an=0;
   xd.append(xda);
+  xda.Label="Q1";
+  xda.pos.x=-0.81649658102978810529098386315336;
+  xda.pos.y=-0.4714045208499572479996295714055;
+  xda.pos.z=0.333333;
+  xda.peakHeight=0.91;
+  xda.uc.m11=0.05;
+  xda.uc.m22=0.05;
+  xda.uc.m33=0.05;
+  xda.uc.m13=0.0;
+  xda.uc.m12=0.0;
+  xda.uc.m23=0.0;
+  xda.an=-1;
+  xd.append(xda);
+  xda.Label="Q2";
+  xda.pos.x=0.81649658102978810529098386315336;
+  xda.pos.y=0.4714045208499572479996295714055;
+  xda.pos.z=0.333333;
+  xda.peakHeight=0.41;
+  xda.uc.m11=0.05;
+  xda.uc.m22=0.05;
+  xda.uc.m33=0.05;
+  xda.uc.m13=0.0;
+  xda.uc.m12=0.0;
+  xda.uc.m23=0.0;
+  xda.an=-1;
+  xd.append(xda);
+  xda.Label="Q3";
+  xda.pos.x=0;
+  xda.pos.y=-0.94280904169991449599925914281199;
+  xda.pos.z=0.333333;
+  xda.peakHeight=0.71;
+  xda.uc.m11=0.05;
+  xda.uc.m22=0.05;
+  xda.uc.m33=0.05;
+  xda.uc.m13=0.0;
+  xda.uc.m12=0.0;
+  xda.uc.m23=0.0;
+  xda.an=-1;
+  xd.append(xda);
   bonds=mol->connecting(xd,true);
   xd[0].an=0;//das ist ein ... trick um bindungen vom zentralatom zu den liganden zu erzeugen.
   /*
@@ -164,7 +207,7 @@ void EacGLW::draw(){
   glRotated(rtx,0.0,1.0,0.0);
   rtx+=0.5;
   mol->dratom=0;
-  mol->nonPositiveDefinite=0;
+  //mol->nonPositiveDefinite=0;
 //  mol->parthigh=false;
   glPushMatrix();
   glScaled( 50, 50, 50 );
@@ -182,6 +225,7 @@ void EacGLW::draw(){
   mol->intern=0;
   mol->dratom=0;
   mol->atoms(xd,proba);
+  mol->lbond();
   glDisable(GL_BLEND);
   glColor3f(0,0,0);
   glClear( GL_DEPTH_BUFFER_BIT);
@@ -206,7 +250,7 @@ void EacGLW::initializeGL(){
   const GLfloat  position[] = {100.0f, 100.0f,100.0f,0.0f};
   const GLfloat  diffuse[]  = { 1.0, 1.0, 1.0, 1.0 };
   const GLfloat  specular[] = { 1.0, 0.9, 0.9, 1.0 };
-  const GLfloat  ambient[]  = { 0.6, 0.6, 0.6, 1.0 };
+  const GLfloat  ambient[]  = { 0.4, 0.4, 0.4, 1.0 };
 
   glLightModeli(  GL_LIGHT_MODEL_LOCAL_VIEWER, 1 );
 
@@ -492,6 +536,15 @@ void EacDlg::strengthChanged(double d){
   update();
 }
 
+void EacDlg::QPeakRadChanged(double d){
+eacGLW->mol->qPeakRad=mol->qPeakRad=d;
+  mol->einstellung->beginGroup("QPeaks");
+  mol->einstellung->setValue("QPeaksRadius",mol->qPeakRad);
+  mol->einstellung->endGroup();
+//settings...
+update();	
+}
+
 void EacDlg::lodChanged(int d){
   eacGLW->mol->LOD=d;
   mol->einstellung->beginGroup("Window");
@@ -752,6 +805,8 @@ EacDlg::EacDlg(Molecule *externMole){
   glt2->addWidget(bondStrength);
   QLabel *bsl = new QLabel("Bond strength");
   QLabel *lodl = new QLabel("Level of detail");
+  QLabel *qradl = new QLabel("QPeak-size");
+  glt2->addWidget(bsl);
   lodSpinBox = new QSpinBox();
   lodSpinBox->setValue(mol->LOD);
   lodSpinBox->setMinimum(2);
@@ -761,9 +816,21 @@ EacDlg::EacDlg(Molecule *externMole){
   glt3->addWidget(lodSpinBox);
   glt3->addWidget(lodl);
 
-  glt2->addWidget(bsl);
+  QDoubleSpinBox* qPeakSizeSBx = new QDoubleSpinBox();
+  qPeakSizeSBx->setValue(mol->qPeakRad);
+  qPeakSizeSBx->setDecimals(3);
+  qPeakSizeSBx->setMinimum(0.005);
+  qPeakSizeSBx->setMaximum(0.5);
+  qPeakSizeSBx->setSingleStep(0.003);
+  qPeakSizeSBx->setToolTip("QPeak-size");
+  connect(qPeakSizeSBx,SIGNAL(valueChanged(double)),this,SLOT(QPeakRadChanged(double)) );
+  QHBoxLayout *glt4= new QHBoxLayout();
+  glt4->addWidget(qPeakSizeSBx);
+  glt4->addWidget(qradl);
+
   glt->addLayout(glt2);
   glt->addLayout(glt3);
+  glt->addLayout(glt4);
   globalStuff->setLayout(glt);
   walbx = new QCheckBox("Draw intersecting planes");
   walbx->setTristate();
@@ -859,7 +926,7 @@ EacDlg::EacDlg(Molecule *externMole){
 }
 
 void EacDlg::doMulti(){
-  multiStyle *m = new multiStyle(mol);
+  MultiStyle *m = new MultiStyle(mol);
   if (m->exec()==QDialog::Accepted){
     int stt=0;
     if (m->sphbx->checkState())stt|=ATOM_STYLE_SPHERE;
@@ -878,7 +945,7 @@ void EacDlg::doMulti(){
   }
 }
 
-multiStyle::multiStyle(Molecule *externMole){
+MultiStyle::MultiStyle(Molecule *externMole){
   mol=externMole;
   setWindowTitle("Multiple Elements Styler");  
   QStringList psel;
@@ -929,13 +996,13 @@ multiStyle::multiStyle(Molecule *externMole){
   setLayout(eacGLO);
 }
 
-void multiStyle::checkWall(){
+void MultiStyle::checkWall(){
   if (sldbx->checkState()&&(walbx->checkState()))walbx->setCheckState(Qt::Unchecked);
 }
-void multiStyle::checkSolid(){
+void MultiStyle::checkSolid(){
   if (sldbx->checkState()&&(walbx->checkState()))sldbx->setCheckState(Qt::Unchecked);
 }
-void multiStyle::checkBall(){
+void MultiStyle::checkBall(){
   if (sphbx->checkState())sldbx->setEnabled(true);
   else sldbx->setEnabled(false);
 }
@@ -966,6 +1033,8 @@ void EacDlg::reject(){
   }
   mol->einstellung->endArray();
   mol->einstellung->endGroup();
+  mol->pmin=eacGLW->exmin;
+  mol->pmax=eacGLW->exmax;
 
   psew->esm->disconnect();
   delete psew->esm;
