@@ -41,7 +41,7 @@ FcVsFo::FcVsFo(QString filename,double a,double b, double c, double al, double b
   brw->setLineWrapMode(QTextEdit::NoWrap);
   brw->setHtml("<h1>Selected Reflections</h1>");
 
-  scene= new gv(-30,-10,550,530);
+  scene= new GraphSceene(-30,-10,550,530);
   scene->setBackgroundBrush(QBrush(QColor("#e9f7d6")));
   scene->clear ();
 
@@ -176,7 +176,7 @@ void FcVsFo::readFCF(){
   //qDebug()<<test<<test.contains(QRegExp("\\s*\\d+\\s*\\d+\\s*\\d+\\s*\\d+\\.\\d+\\s*\\d+\\.\\d+\\s*\\d+"));
   if (test.contains(QRegExp("\\s*\\d+\\s*\\d+\\s*\\d+\\s*\\d+\\.\\d+\\s*\\d+\\.\\d+\\s*\\d+"))) listType=2;
   if (test.contains(QRegExp("\\s*\\d+\\s*\\d+\\s*\\d+\\s*\\d+\\.\\d+\\s*\\d+\\.\\d+\\s*\\d+\\.\\d+"))) listType=5;
-  if (test.startsWith("#")){
+  if ((test.startsWith("#"))||(test.startsWith("data"))){
     while (!test.isEmpty()){
       test=QString(f.readLine(120));
       if (test.startsWith("_shelx_refln_list_code")){
@@ -187,7 +187,7 @@ void FcVsFo::readFCF(){
       }
     }  
   }
-//  printf("list type %d \n",listType);
+  //printf("list type %d \n",listType);
   QStringList tok;
   Refls obs,cal;
   double a,b;
@@ -356,6 +356,38 @@ void FcVsFo::readFCF(){
 		 }
 		 //		 qDebug()<<"List6 OK";
 
+		 break;
+	  case 7:{
+
+		 }
+		 break;
+	  case 8:{
+
+		   f.reset();
+		   lines=QString(f.readAll()).split(QRegExp("[\\r\\n]"),QString::SkipEmptyParts);
+
+		   int i= 0;
+		   for (int j=0; (!j)&&(i<lines.size()); i++){
+		     if (lines.at(i).contains("_shelx_refinement_sigma")) j++;
+		   }
+//		    qDebug()<<i<<lines.at(i-1);
+		   for (; i<lines.size(); i++){
+		     tok=lines.at(i).split(' ',QString::SkipEmptyParts);
+		     if (!tok.isEmpty()&&(tok.size()==9)){
+		       obs.h= cal.h=tok.at(0).toInt();
+		       obs.k= cal.k=tok.at(1).toInt();
+		       obs.l= cal.l=tok.at(2).toInt();
+		       obs.F= sqrt(fabs(tok.at(3).toDouble()));
+		       cal.sigma=obs.sigma=tok.at(4).toDouble();
+		       cal.F= sqrt(fabs(tok.at(5).toDouble()));
+		       obs.phase=cal.phase=tok.at(6).toDouble();
+		       obs.stl=cal.stl=1.0/(2.0*tok.at(7).toDouble());
+		       obs.w=tok.at(8).toDouble();
+		       Fc.append(cal);
+		       Fo.append(obs);
+		     }
+		   }
+		 }
 		 break;
 	  default:
 		 break;
@@ -523,11 +555,11 @@ void  FcVsFo::graphChange(int type){
 }
 
 
-gv::gv( qreal x, qreal y, qreal width, qreal height, QObject * parent ) :QGraphicsScene (  x,  y, width,  height, parent){
+GraphSceene::GraphSceene( qreal x, qreal y, qreal width, qreal height, QObject * parent ) :QGraphicsScene (  x,  y, width,  height, parent){
 //constructor 
 } 
 
-void gv::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
+void GraphSceene::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
   qreal  x= mouseEvent->scenePos().x(),
 	 y= mouseEvent->scenePos().y();
 //  qDebug()<<mouseEvent->buttons()<< mouseEvent->buttonDownScreenPos (Qt::LeftButton);
@@ -564,7 +596,7 @@ void gv::mouseMoveEvent ( QGraphicsSceneMouseEvent  * mouseEvent ){
   }
 }
 
-void gv::mousePressEvent ( QGraphicsSceneMouseEvent * mouseEvent ){
+void GraphSceene::mousePressEvent ( QGraphicsSceneMouseEvent * mouseEvent ){
    if (mouseEvent->button()==Qt::LeftButton){
      selEckt->setRect(0,0,0,0);
      selected.clear();
@@ -586,4 +618,9 @@ else{
   state->setText(s);
 }
 }
-
+#ifdef vc7hack
+#include <float.h>
+int isnormal(double arg){
+    return _finite(arg)||(arg==0);
+}
+#endif
