@@ -65,7 +65,18 @@
    "SIMU"<<"SIZE"<<"SPEC"<<"SPIN"<<"STIR"<<"SUMP"<<"SWAT"<<"SYMM"<<
    "TEMP"<<"TEXP"<<"TIME"<<"TITL"<<"TREF"<<"TWIN"<<"UNIT"<<"VECT"<<
    "WPDB"<<"WGHT"<<"ZERR"<<"XNPD"<<"REST"<<"CHAN"<<"RIGU"<<"FLAP"<<
-   "RNUM"<<"SOCC"<<"PRIG"<<"WIGL"<<"RANG"<<"TANG"<<"ADDA"<<"STAG";
+   "RNUM"<<"SOCC"<<"PRIG"<<"WIGL"<<"RANG"<<"TANG"<<
+   "ADDA"<<
+   "STAG"<<
+   "ATOM"<<//PDB dummy commands ...
+   "HETA"<<//PDB dummy commands ...
+   "SCAL"<<//PDB dummy commands ...
+	  "ABIN"<<
+	  "ANSC"<<
+	  "ANSR"<<
+	  "NOTR"<<
+	  "NEUT"<<
+	  "TWST";//<<
    
    ;
   foreach (QString pattern, keywordPatterns) {
@@ -218,16 +229,17 @@
 }
 
 void Highlighter::setOutputStyle(){
+  QColor white=QColor(255,255,230);
   QTextCharFormat realFormat;
   realFormat.setForeground(Qt::red);
-  realFormat.setBackground(Qt::white);
+  realFormat.setBackground(white);
 
   QTextCharFormat labelFormat;
   labelFormat.setForeground(Qt::black);
   labelFormat.setBackground(Qt::lightGray);
 
   QTextCharFormat plusFormat;
-  plusFormat.setForeground(Qt::white);
+  plusFormat.setForeground(white);
   plusFormat.setBackground(Qt::darkBlue);
   //plusFormat.setFontPointSize(7);
 
@@ -239,7 +251,7 @@ void Highlighter::setOutputStyle(){
 
   QTextCharFormat intFormat;
   intFormat.setForeground(Qt::blue);
-  intFormat.setBackground(Qt::white);
+  intFormat.setBackground(white);
   HighlightingRule rule;
   highlightingRules.clear();
   rule.pattern =  QRegExp("\\b[0-9]+\\b");
