@@ -19,13 +19,13 @@
 #include "historywidget.h"
 #include <QtGui>
 #define PROGRAM_NAME "shelXle"
-historyWidget::historyWidget(QWidget *parent) :
+HistoryWidget::HistoryWidget(QWidget *parent) :
     QWidget(parent){
     setMinimumSize(100,100);
     setMouseTracking(true);
 }
 
-void historyWidget::mouseMoveEvent(QMouseEvent *event){
+void HistoryWidget::mouseMoveEvent(QMouseEvent *event){
     if (event->pos().y()<6) {
         emit message("");
         return;
@@ -37,7 +37,7 @@ void historyWidget::mouseMoveEvent(QMouseEvent *event){
     emit message(QString("%1 (R1=%2)").arg(saveFilesList.at(index)).arg(RWerte.at(index)));
 }
 
-void historyWidget::preview(){
+void HistoryWidget::preview(){
     QAction *action = qobject_cast<QAction *>(sender());
     QString fileName = "";
     if (action)
@@ -60,7 +60,7 @@ void historyWidget::preview(){
 
 }
 
-void historyWidget::preview2(){
+void HistoryWidget::preview2(){
     QAction *action = qobject_cast<QAction *>(sender());
     QString fileName = "";
     if (action)
@@ -84,7 +84,7 @@ void historyWidget::preview2(){
 
 }
 
-void historyWidget::prune(){
+void HistoryWidget::prune(){
   QString fcfname;
   for (int i=0; (i+10)<saveFilesList.size(); i++){
     QFile::remove(saveFilesList.at(i));
@@ -95,7 +95,7 @@ void historyWidget::prune(){
   setPath(dirname,maxwid);
 }
 
-void historyWidget::deleteOne(){
+void HistoryWidget::deleteOne(){
     QAction *action = qobject_cast<QAction *>(sender());
     QString fileName = "";
     if (action)
@@ -116,7 +116,7 @@ void historyWidget::deleteOne(){
 }
 
 
-void historyWidget::mousePressEvent ( QMouseEvent * event ){
+void HistoryWidget::mousePressEvent ( QMouseEvent * event ){
   if  (RWerte.isEmpty()) return;
   int w = width() / RWerte.size();
   int index = qMin(event->pos().x() / w, saveFilesList.size()-1);//event->pos().x() / w;
@@ -165,7 +165,7 @@ void historyWidget::mousePressEvent ( QMouseEvent * event ){
 	QFile::copy(dirname,QString("%1/%4saves/%2_%3_.ins").arg(dn).arg(argument).arg(vers,2,36,QLatin1Char('0')).arg(PROGRAM_NAME));
 	QFile::remove(dirname);
 	QFile::copy(saveFilesList.at(index),dirname);
-	QFile::remove(saveFilesList.at(index));
+//	QFile::remove(saveFilesList.at(index));
 
         QFile::copy(fcfname,QString("%1/%4saves/%2_%3_.fcf").arg(dn).arg(argument).arg(vers,2,36,QLatin1Char('0')).arg(PROGRAM_NAME));
         QFile::remove(fcfname);
@@ -178,7 +178,9 @@ void historyWidget::mousePressEvent ( QMouseEvent * event ){
 	QFile::copy(insname,QString("%1/%4saves/%2_%3_.ins").arg(dn).arg(argument).arg(vers,2,36,QLatin1Char('0')).arg(PROGRAM_NAME));
 	QFile::remove(insname);
 	QFile::copy(dirname,insname);
-	QFile::remove(dirname);
+	if (saveFilesList.at(index) != dirname) {
+	  QFile::remove(dirname);
+	}
         QFile::copy(fcfname2,QString("%1/%4saves/%2_%3_.fcf").arg(dn).arg(argument).arg(vers,2,36,QLatin1Char('0')).arg(PROGRAM_NAME));
         QFile::remove(fcfname2);
         QFile::copy(fcfname,fcfname2);
@@ -188,7 +190,7 @@ void historyWidget::mousePressEvent ( QMouseEvent * event ){
         QFile::copy(sfcf,fcfname);
 
 	QFile::copy(saveFilesList.at(index),dirname);
-	QFile::remove(saveFilesList.at(index));
+	//QFile::remove(saveFilesList.at(index));
         //printf("copy %s to %s\n",fcfname.toStdString().c_str()
         //		,fcfname2.toStdString().c_str());
         //printf("copy %s to %s\n",fcfname2.toStdString().c_str()
@@ -226,7 +228,7 @@ void historyWidget::mousePressEvent ( QMouseEvent * event ){
   update();
 }
 
-void historyWidget::setPath(QString dirName,int wid){
+void HistoryWidget::setPath(QString dirName,int wid){
   maxwid = wid-5;
   dirname=dirName;
   QString dn = dirName.section('/',0,-2),
@@ -331,7 +333,7 @@ void historyWidget::setPath(QString dirName,int wid){
       update();
 }
 
-QColor historyWidget::farbverlauf(double wrt){
+QColor HistoryWidget::farbverlauf(double wrt){
   int rot,gruen,blau,alpha;
   int lauf=0;
   const float farbe[6][4]={
@@ -355,7 +357,7 @@ QColor historyWidget::farbverlauf(double wrt){
   return QColor(rot,gruen,blau,alpha);
 }
 
-void historyWidget::paintEvent(QPaintEvent *event){
+void HistoryWidget::paintEvent(QPaintEvent *event){
 
   double x =0;
   for (int i=0; i<RWerte.size(); i++){
@@ -395,7 +397,7 @@ void historyWidget::paintEvent(QPaintEvent *event){
   //p.drawText(0,0,p.fontMetrics().width("1234567890"),p.fontMetrics().height(),Qt::AlignLeft,QString("%1 %2").arg(h).arg(w));
 }
 
-bool historyWidget::event(QEvent *event){
+bool HistoryWidget::event(QEvent *event){
   if (!isVisible()) {event->ignore(); return false;}
   if (event->type() == QEvent::ToolTip) {
     QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
