@@ -24,20 +24,26 @@
 #include <QDebug>
 #include <QToolButton>
 #include "molecule.h"
+/*! \brief PSEWidget is a widget that features a periodic table of the elements. 
+ *
+ *  The color scheme is given by the molecule class and the settings given there.
+ *  
+ *  The elements in the table can be clicked to select one of them.
+ */ 
 class PSEWidget : public QWidget
 {
     Q_OBJECT
 public:
     explicit PSEWidget(QWidget *parent = 0);
-    int selection;
+    int selection;//!< The curent selected element starting from zero which refers to Hydrogen 
     QSignalMapper* esm;
 signals:
-void pseSelected(int index);
+void pseSelected(int index);//!< This signal is emitted when an element is clicked.
 public slots:
-void selectPSE(int index){selection=index; emit pseSelected(index);}
-void incFontSize();
-void decFontSize();
-void colorchange(QColor bgcolor);
+void selectPSE(int index){selection=index; emit pseSelected(index);}//!< Change the current element by the program.
+void incFontSize();//!< Increase the font size of the Elements by one point.
+void decFontSize();//!< Decrease the font size of the Elements by one point.
+void colorchange(QColor bgcolor); //! Assign a new color to the current element.
 private:
 int sz; 
 Molecule mole;
