@@ -21,7 +21,7 @@
 
 QPeakView::QPeakView(QWidget *parent) :
     QWidget(parent){
-    //Dieses Widget soll einen Farbverlauf mit Peak-HÃ¶hen darstellen
+    //Dieses Widget soll einen Farbverlauf mit Peak-Hoehen darstellen
     min=0;
     focusHeight=-1.0;
     max=80.0;
@@ -32,7 +32,7 @@ QPeakView::QPeakView(QWidget *parent) :
 }
 
 void QPeakView::unhide(){
-    oco=cutoff=qMin(0.0,min);
+    oco=cutoff=0;//qMin(0.0,min);
     update();
 }
 
@@ -63,19 +63,33 @@ void QPeakView::paintEvent(QPaintEvent *event){
 
     QBrush b;
     for (int i = 0; i < v; i++){
+        u=(1.0-i/w)*max+(i/w)*min;
         if (QString::number(focusHeight,'f',2)==QString::number((1.0-i/w)*max+(i/w)*min,'f',2)){
             p.setPen(Qt::yellow);
             b.setColor(Qt::darkGray);
             p.fillRect(20,i*fh,50,fh,b);
         }
-        else p.setPen(Qt::black);
-        u=(1.0-i/w)*max+(i/w)*min;
-        if (u>=cutoff) p.drawText(20,i*fh,40,fh,Qt::AlignLeft,QString::number(u,'f',2));
+        else {
+            p.setPen(Qt::black);
+            if (u<0)p.setPen(Qt::red);
+        }
         //printf("%f %f %f %f %f %d %d\n",v,w,u,min,max,h,fh);
-        if ((u)<cutoff) b.setStyle(Qt::Dense3Pattern);
-        else b.setStyle(Qt::SolidPattern);
+        if (cutoff>0) {
+            if (((u)<cutoff)&&(u>0)) b.setStyle(Qt::Dense3Pattern);
+            else b.setStyle(Qt::SolidPattern);
+        }
+        else {
+            if (((u)>cutoff)&&(u<0)) b.setStyle(Qt::Dense3Pattern);
+            else b.setStyle(Qt::SolidPattern);
+        }
         b.setColor(farbverlauf(u));
-        p.fillRect(0,i*fh,(u<cutoff)?50:20,fh,b);
+        if (cutoff>0)
+            p.fillRect(0,i*fh,((u<cutoff)&&(u>0))?50:20,fh,b);
+        else p.fillRect(0,i*fh,((u>cutoff)&&(u<0))?50:20,fh,b);
+
+        if (cutoff>0) {if ((u>=cutoff)||(u<0)) p.drawText((u<0)?12:20,i*fh,40,fh,Qt::AlignLeft,QString::number(u,'f',2));}
+        else {if ((u<cutoff)||(u>0)) p.drawText((u<0)?12:20,i*fh,40,fh,Qt::AlignLeft,QString::number(u,'f',2));}
+
     }
 }
 
