@@ -126,6 +126,7 @@ public:
   void dispFromWave();//!<calculates f', f" and mu for the given wavelength and inserts DISP lines for each SFAC entry.
   void doMapsNow(bool b);//!<destroys maps or (re)calculates them freshly.
   int duplicates();//!<searches for identical labeled Atoms and add them to a list. 
+  void editorIsVisible(bool);//!is Editor really visble
   void effuenf();//!<F5 recalculates the display lists sets the focus to the openGL widget and raises it on top. 
   void expandAll();//!<Expands all contacts .
   void extraSettings();//!<A dialog to add/edit exteral programs started from ShelXle with or without arguments.
@@ -141,40 +142,42 @@ public:
   void findResi(QString);//!<Searches a Residue via a string like "RESI 22 ALA" or "RESI ALA 22" in the editor and selects all atoms with the same residue number (eg: 22).
   void findText();//!<Find functionality of search and replace in the editor.
   void findText2();//!<Find functionality of search in the list view.  
-  void fixIt();//!<Fix some parameters from being refined.
-  void foversusfc();//!<Shows a duialog to analyse and omit outlier reflections.
-  void fuse();//!<show only the asymetric unit.
+  void fixIt();//!< Fix some parameters from being refined.
+  void foversusfc();//!< Shows a duialog to analyse and omit outlier reflections.
+  void fuse();//!< show only the asymetric unit.
   void grossRC(const QString &text);//!< Capitalizes the text and sets the resiResiClass text to text @param text new text for resiResiClass.
-  void grow();//!<completes the molecule by symmetry.
-  void growQPeaks(bool qpg);//!<applies symmetrie operations used for the main structure also for the Q-Peaks.
-  void hideSearch();//!<Hides the search and replace widget for the editor.
-  void hideSearch2();//!<Hides the search widget for the list view.
-  void hideToolz(bool b);//!<Hides all tool bars.
-  void hintLhide();//!<Hides a hint in the reaname mode for ever.
-  void increaseEdtiorFont();//!<Increases the editor font by one point.
-  void infoKanalNews(const QString& s);//!<passes a string to the Info widget. @param s a new text for the info widget.
-  void inheritLabels();//!<opens an inherit labels dialog.
-  bool insertAnis();//!<inserts anis instruction into the file.
-  void insertBind();//!<inserts a BIND instruction into the file.
-  void insertFree();//!<inserts a FREE instruction into the file.
-  void insertList6();//!<inserts a LIST 6 instruction into the file.
-  void invert();//!<inverts the structure and changes ot the right enantiomorph space group.
+  void grow();//!< completes the molecule by symmetry.
+  void growQPeaks(bool qpg);//!< applies symmetrie operations used for the main structure also for the Q-Peaks.
+  void hideSearch();//!< Hides the search and replace widget for the editor.
+  void hideSearch2();//!< Hides the search widget for the list view.
+  void hideToolz(bool b);//!< Hides all tool bars.
+  void hintLhide();//!< Hides a hint in the reaname mode for ever.
+  void increaseEdtiorFont();//!< Increases the editor font by one point.
+  void infoKanalNews(const QString& s);//!< passes a string to the Info widget. @param s a new text for the info widget.
+  void inheritLabels();//!< opens an inherit labels dialog.
+  bool insertAnis();//!< inserts anis instruction into the file.
+  void insertBind();//!< inserts a BIND instruction into the file.
+  void insertFree();//!< inserts a FREE instruction into the file.
+  void insertList6();//!< inserts a LIST 6 instruction into the file.
+  void invert();//!< inverts the structure and changes ot the right enantiomorph space group.
 //  inline int Intersect( double& vm, double& vp ){ return vm*vp <= 0.0 && (vm<0.0 || vp<0.0); }//!<
-  void isUpToDate(QNetworkReply* antwort);//!<Interpretes the network reply for the check for updates (manual version)
-  void jumpToAtom(int index);//!<if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom. 
-  void jumpToError();//!<the cursor points to the first syntax error in the file.
-  void loadAFile();//!<(re)loads the file specified in dirName.
-  void loadFile(QString fileName);//!<loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
-  void loadLst();//!<loads the .lst file if it exists.
-  void loadrefres();//!<loads the refinement results from the res file.
-  void mapDefault();//!<restores the defaults of the Map Control dialog.
-  void moveSymmMate();//!<Moves the specified symmetry generated atom to the asymmetric unit. 
-  void moveSymmMateSel();//!<Moves selected symmetry generated atoms to the asymmetric unit.
+  void isUpToDate(QNetworkReply* antwort);//!< Interpretes the network reply for the check for updates (manual version)
+  void jumpToAtom(int index);//!< if rename mode is visible the atom at index gets renamed if not the cursor of the editor is pointed to the specified atom.
+  void jumpToError();//!< the cursor points to the first syntax error in the file.
+  void loadAFile();//!< (re)loads the file specified in dirName.
+  void loadFile(QString fileName);//!< loads the file with the specified path the listfile is also loaded. @param fileName path to the res / ins file.
+  void loadLst();//!< loads the .lst file if it exists.
+  void loadrefres();//!< loads the refinement results from the res file.
+  void mapDefault();//!< restores the defaults of the Map Control dialog.
+  void moveSymmMate();//!< Moves the specified symmetry generated atom to the asymmetric unit.
+  void moveSymmMateSel();//!< Moves selected symmetry generated atoms to the asymmetric unit.
   void omitsome(const QString &s);//!< insetrts a 'OMIT h k l\n' string in the res file.  
-  void openFile();//!<Open res file dialog
+  void openFile();//!< Open res file dialog
   void openMapControl();//!< shows the Map Control dialog.
   void openRecentFile();//!< opens a recently used file
   void openSaveHistory();//!< sows the save history dialog
+  void outputIsVisible(bool);//!< is Output really visble
+
 //  bool peakcomp(MyAtom &a1,MyAtom &a2);
   void redoRename();//!<if redo is clicked and it was a rename a rename is redone.
   void removeExtra(QAbstractButton *button);//!<removes an external program from the menu / tool bar.
@@ -216,6 +219,7 @@ public:
   void styleDialog();//!< Atom style dialog is shown.
   void symmetryManager();//!< a symmetry manager is shown 
   void toggDocWid(bool weg);//!< hides Text Windows
+  void toggleEQHighlighting(bool);//!< toggles higlighting of symmetry generated atoms.
   void toggleOrtho(bool ov);//!< toggles orthographic and perspective projection.
   void trick();//!< a (dirty) trick to show the GLWidget in the right way all the time. 
   void undoRename();//!<if undo is clicked and it was a rename a rename is undone.
@@ -415,6 +419,7 @@ private:
       *killQs,
       *killHs,
       *astdlg,
+  *equivHighlighting,
       *mapcontrol,
       *wghtAct,
       *sinaAct;
@@ -429,6 +434,7 @@ private:
   QString load_sheldrick(QString fileName);
   bool maybeSave();  
   bool maybeSave2();
+  bool ediVis,oupVis;
 };
 #endif
 
